pub struct InMemoryStorageProxyBackend { /* private fields */ }Available on crate feature
testing only.Expand description
An in-memory backend authorizing a single securable and key prefix.
Implementations
Sourceimpl InMemoryStorageProxyBackend
impl InMemoryStorageProxyBackend
Sourcepub fn table(full_name: impl Into<String>) -> Self
pub fn table(full_name: impl Into<String>) -> Self
A backend authorizing the whole of the given table: securable, read+write,
over a fresh empty store.
Sourcepub fn volume(full_name: impl Into<String>) -> Self
pub fn volume(full_name: impl Into<String>) -> Self
A backend authorizing the whole of the given vol: securable, read+write.
Sourcepub fn with_prefix(self, prefix: impl Into<String>) -> Self
pub fn with_prefix(self, prefix: impl Into<String>) -> Self
Restrict authorized keys to those under prefix (drives out-of-scope tests).